==> foundation-ui-components-1.24.1.tgz: package/src/common/card/NsHeroCardLevel1.tsx <==
import { NsImage } from '../';
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import CardButton from './CardButton';
import { NsCardButton } from './types';

type NsHeroCardLevel1Props = {
    cardTitle: string;
    cardDescription: string;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    button?: NsCardButton;
    className?: string;
    imagePosition?: 'top' | 'bottom';
};

const CardContainer = styled((props: any) => <Box {...props} />)(({ imagePosition }) => {
    const imageDirection = imagePosition === 'top' ? 'column' : 'column-reverse';

    return {
        backgroundClip: 'border-box',
        display: 'flex',
        wordWrap: 'break-word' as 'break-word',
        position: 'relative',
        overflow: 'hidden',
        maxWidth: '820px',
        height: '532px',
        flexDirection: 'row',
        '.content': {
            width: '50%',
            minWidth: '300px',
            height: '500px',
            padding: '50px',
            paddingLeft: '100px',
            display: 'flex',
            flexDirection: 'column' as 'column',
            position: 'absolute',
            top: 0,
            left: 0,
            boxSizing: 'border-box',
        },
        '.bg-image': {
            objectFit: 'cover',
        },
        '.body-title': {
            fontSize: '36px',
            lineHeight: '44px',
            marginBottom: '20px',
        },
        '.body-text': {
            fontSize: '18px',
            marginBottom: '20px',
        },
        '.action-link': {
            marginTop: '10px',
        },
        '@media (max-width: 768px)': {
            '.content': {
                paddingLeft: '20px',
            },
        },
        '@media (max-width: 430px)': {
            height: 'auto',
            backgroundColor: '#edece9',
            flexDirection: imageDirection,
            '.content': {
                height: 'auto',
                position: 'static',
                width: '100%',
                padding: '20px',
            },
        },
    };
});

export default function NsHeroCardLevel1({
    cardTitle,
    cardDescription,
    backgroundImageUrl,
    backgroundImageAlt,
    button,
    className,
    imagePosition = 'top',
}: NsHeroCardLevel1Props) {
    return (
        <CardContainer className={className} data-testid="hero-card-level-1" imagePosition={imagePosition}>
            <NsImage variant="fill" alt={backgroundImageAlt} src={backgroundImageUrl} className="bg-image" />
            <div className="content">
                <article className="body-title">{cardTitle}</article>
                <article className="body-text">{cardDescription}</article>
                {button ? <CardButton {...button} /> : null}
            </div>
        </CardContainer>
    );
}

==> foundation-ui-components-1.30.1.tgz: package/src/common/card/NsHeroCardLevel1.tsx <==
import { ReactElement } from 'react';

import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';

import { BynderMedia } from '../image/BynderMedia';
import { BynderImageDataType } from '../image/types';
import CardButton from './CardButton';
import { NsCardButton } from './types';

type NsHeroCardLevel1Props = {
    cardTitle: string;
    cardDescription: string;
    backgroundImageDetail: BynderImageDataType;
    button?: NsCardButton;
    className?: string;
    imagePosition?: 'top' | 'bottom';
};

const CardContainer = styled((props: any) => <Box {...props} />)(({ imagePosition }) => {
    const imageDirection = imagePosition === 'top' ? 'column' : 'column-reverse';

    return {
        backgroundClip: 'border-box',
        display: 'flex',
        wordWrap: 'break-word' as 'break-word',
        position: 'relative',
        overflow: 'hidden',
        maxWidth: '820px',
        height: '532px',
        flexDirection: 'row',
        '.content': {
            width: '50%',
            minWidth: '300px',
            height: '500px',
            padding: '50px',
            paddingLeft: '100px',
            display: 'flex',
            flexDirection: 'column' as 'column',
            position: 'absolute',
            top: 0,
            left: 0,
            boxSizing: 'border-box',
        },
        '.bg-image': {
            objectFit: 'cover',
        },
        '.body-title': {
            fontSize: '36px',
            lineHeight: '44px',
            marginBottom: '20px',
        },
        '.body-text': {
            fontSize: '18px',
            marginBottom: '20px',
        },
        '.action-link': {
            marginTop: '10px',
        },
        '@media (max-width: 768px)': {
            '.content': {
                paddingLeft: '20px',
            },
        },
        '@media (max-width: 430px)': {
            height: 'auto',
            backgroundColor: '#edece9',
            flexDirection: imageDirection,
            '.content': {
                height: 'auto',
                position: 'static',
                width: '100%',
                padding: '20px',
            },
        },
    };
});

export default function NsHeroCardLevel1({
    cardTitle,
    cardDescription,
    backgroundImageDetail,
    button,
    className,
    imagePosition = 'top',
}: NsHeroCardLevel1Props): ReactElement {
    return (
        <CardContainer className={className} data-testid="hero-card-level-1" imagePosition={imagePosition}>
            <BynderMedia className="bg-image" imageDetail={backgroundImageDetail} />
            <div className="content">
                <article className="body-title">{cardTitle}</article>
                <article className="body-text">{cardDescription}</article>
                {button ? <CardButton {...button} /> : null}
            </div>
        </CardContainer>
    );
}
